@@ -28,5 +28,6 @@ void profiles_launcher_vpnc_init();
 void profiles_launcher_vpnc_set_event_callback(void (*callback)(struct profile *, gint event, gpointer data));
 void profiles_launcher_vpnc_connect(struct profile *p);
 void profiles_launcher_vpnc_disconnect(struct profile *p);
-void profiles_launcher_vpnc_feed_password(struct profile *p, const gchar *pw);
+void profiles_launcher_vpnc_feed_password(gchar *pw);
+
 #endif
